import { Component, OnInit } from '@angular/core';
import { EmailValidator, FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { Router } from '@angular/router';
import Swal from 'sweetalert2';
import { Login } from '../../services/login.sevice';
@Component({
  selector: 'app-change-password',
  templateUrl: './change-password.component.html',
  styleUrls: ['./change-password.component.css']
})
export class ChangePasswordComponent implements OnInit {
  loginForm: FormGroup;
  hide = true;
  constructor(private fb: FormBuilder, private router: Router, private loginService : Login) { }

  ngOnInit(): void {
    this.loginForm = this.fb.group({
      new_password:["",[Validators.required]],
      confirmPassword:["",[Validators.required]],
    })
    
  }

  getEmailError(){
    if(this.loginForm.controls.username.hasError('required')){
      return 'Required'
    }else{
      return ''
    }
  }

  getPasswordError(){
    if(this.loginForm.controls.new_password.hasError('required')){
      return 'Required'
    }else{
      return ''
    }
  }

  
  login(){ 
    if(!this.loginForm.valid){

      Swal.fire({
        text: "Please enter all the fields in the right format.",
        icon: "error"
      }).then((res) => {
      }) 
    }
    else{
      if(this.loginForm.get("new_password").value != this.loginForm.get("confirmPassword").value){
        Swal.fire({
          text: "Passwords don't match!",
          icon: "error"
        }).then((res) => {
        }) 
      }
      else{
      this.loginForm.removeControl('confirmPassword');
        this.loginService.changePassword(this.loginForm.value).subscribe((res) => {
          Swal.fire({
            text: "Password Changed Successfully!",
            icon: "success"
          }).then((res) => {
            this.loginService.checkStatus().subscribe((res) => {

              if(res[0] == undefined){
                this.router.navigateByUrl("/preSurvey")
              }
              else{
                if(res[0]["postsurveystatus"] == true){
                  this.router.navigateByUrl("/final")
                }
                else if(res[0]["scoresstatus"] == true){
                  this.router.navigateByUrl("/score")
                }
                else if(res[0]["finalfeedbackstatus"] == true){
                  this.router.navigateByUrl("/result")
                }
                else if(res[0]["cpcqstatus"] == true){
                  this.router.navigateByUrl("/finalFeedback")
                }
                else if(res[0]["responsesstatus"] == true){
                  this.router.navigateByUrl("/unpacking")
                }
                else if(res[0]["presurveystatus"] == true){
                  this.router.navigateByUrl("/dashboard")
                }
              }
            })
          }) 
  
        },(err) => {
          
          Swal.fire({
            text: "Username/Email already exists",
            icon: "error"
          }).then((res) => {
          }) 
        })
      }
          
  }
  }

}
