import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { Router } from '@angular/router';
import { map } from 'rxjs/operators';
import Swal from 'sweetalert2';
import { Login } from '../../services/login.sevice';
@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.css']
})
export class LoginComponent implements OnInit {
  loginForm: FormGroup;
  hide = true;
  constructor(private fb: FormBuilder, private router: Router, private loginService : Login) { }

  ngOnInit(): void {
    this.loginForm = this.fb.group({
      username:["",[Validators.required]],
      password:["",[Validators.required]]
    })
    
  }

  getEmailError(){
    if(this.loginForm.controls.username.hasError('required')){
      return 'Required'
    }else{
      return ''
    }
  }

  getPasswordError(){
    if(this.loginForm.controls.password.hasError('required')){
      return 'Required'
    }else{
      return ''
    }
  }

  
  login(){ 
    if(!this.loginForm.valid){

      Swal.fire({
        text: "Please enter all the fields in the right format.",
        icon: "error"
      }).then((res) => {
      }) 
    }
    else{
        this.loginService.login(this.loginForm.value).subscribe((res) => {
          
          localStorage.setItem("user",res["token"]);
          localStorage.setItem("study",res["user"]["study_id"])
          Swal.fire({
            text: "Login Successful",
            icon: "success"
          }).then((res) => {
            this.loginService.checkStatus().subscribe((res) => {

              if(res[0] == undefined){
                this.router.navigateByUrl("/preSurvey")
              }
              else{
                if(res[0]["postsurveystatus"] == true){
                  this.router.navigateByUrl("/final")
                }
                else if(res[0]["scoresstatus"] == true){
                  this.router.navigateByUrl("/score")
                }
                else if(res[0]["finalfeedbackstatus"] == true){
                  this.router.navigateByUrl("/result")
                }
                else if(res[0]["cpcqstatus"] == true){
                  this.router.navigateByUrl("/finalFeedback")
                }
                else if(res[0]["responsesstatus"] == true){
                  this.router.navigateByUrl("/unpacking")
                }
                else if(res[0]["presurveystatus"] == true){
                  this.router.navigateByUrl("/dashboard")
                }
              }
            })
          }) 
        },(err) => {
          
          Swal.fire({
            text: "Wrong credentials",
            icon: "error"
          }).then((res) => {
          }) 
        })

      // this.loginService.login(this.loginForm.value).subscribe((res) => {
      //   
      //   var arr = [];
      //   var flag = false;
      //   Object.keys(res).map(function(key){
      //     arr.push({[key]:res[key]})
      //   }) 
      //   
      //   for(var i = 0 ; i<arr.length;i++){
      //     
      //     if((this.loginForm.value["username"] == arr[i][i]["email"]) && (this.loginForm.value["password"] == arr[i][i]["password"])){
      //       flag = true;
      //       Swal.fire({
      //         text: "Login Successful",
      //         icon: "success"
      //       }).then((res) => {
      //         localStorage.setItem("user","test1");
      //         this.router.navigateByUrl("/preSurvey")
      //       }) 
      //     }
      //   }
      //   if(!flag){
      //     Swal.fire({
      //       text: "Wrong credentials",
      //       icon: "error"
      //     }).then((res) => {
      //     }) 
      //   }
      // },(err) =>{

      // })
  }
    // this.loginService.login(this.loginForm.value).subscribe((res) => {
      // var arr = [];
      // Object.keys(res).map(function(key){
      //   arr.push({[key]:res[key]})
      //   return arr
      // }) 
    //   var flag = true;
    //   for(var i = 0; i<arr.length;i++){
    //     
    //     if((this.loginForm.value["username"] == arr[i][`${i}`]['username']) && (this.loginForm.value["password"] == arr[i][`${i}`]['password'])){
    //       flag = false;
    //       Swal.fire({
    //         text: "Login Successful",
    //         icon: "success"
    //       }).then((res) => {
    //         localStorage.setItem("user","test1");
    //         this.router.navigateByUrl("/preSurvey")
    //       }) 
    //     }
    //   }
    //   if(flag){
    //     Swal.fire({
    //       text: "Wrong credentials",
    //       icon: "error"
    //     });
    //   }
    //   // this.router.navigateByUrl("/consent");
    //   // localStorage.setItem("user", res["token"]);
    //   // localStorage.setItem("exID",res["user"]["id"])
    // },(err) => {
    //   
    //   Swal.fire({
    //     text: err.error["message"],
    //     icon: "error"
    //   });
    // })
  }

}
