import { Component, OnInit } from '@angular/core';
import { EmailValidator, FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialog, MatDialogRef } from '@angular/material/dialog';
import { Router } from '@angular/router';
import Swal from 'sweetalert2';
import { Login } from '../../services/login.sevice';
@Component({
  selector: 'app-register-component',
  templateUrl: './register-component.component.html',
  styleUrls: ['./register-component.component.css']
})
export class RegisterComponentComponent implements OnInit {
  loginForm: FormGroup;
  hide = true;
  constructor(private fb: FormBuilder, private router: Router, private loginService : Login) { }

  ngOnInit(): void {
    this.loginForm = this.fb.group({
      username:["",[ Validators.required]],
      email:['',[Validators.required, Validators.email]],
      password:["",[Validators.required]],
      first_name:["",[Validators.required]],
      last_name:[""]

    })
    
  }

  getEmailError(){
    if(this.loginForm.controls.username.hasError('required')){
      return 'Required'
    }else{
      return ''
    }
  }

  getPasswordError(){
    if(this.loginForm.controls.password.hasError('required')){
      return 'Required'
    }else{
      return ''
    }
  }

  
  login(){ 
    if(!this.loginForm.valid){

      Swal.fire({
        text: "Please enter all the fields in the right format.",
        icon: "error"
      }).then((res) => {
      }) 
    }
    else{
      this.loginService.register(this.loginForm.value).subscribe((res) => {
        localStorage.setItem("user",res["token"]);
        Swal.fire({
                  text: "Registration Successful",
                  icon: "success"
                }).then((res) => {
                  this.router.navigateByUrl("/preSurvey")
        })

      },(err) => {
        
        Swal.fire({
          text: "Username/Email already exists",
          icon: "error"
        }).then((res) => {
        }) 
      })    
  }
  }

}
